# API Integration Guide for SupplyChain Pulse

This document provides technical guidance for integrating real data sources with the SupplyChain Pulse platform. While the current implementation uses simulated data, this guide outlines how to connect to external APIs for live data.

## Overview

SupplyChain Pulse is designed to integrate with various data sources to provide real-time information about supply chain disruptions, risks, and industry impacts. This guide explains the integration points and implementation approach.

## Data Integration Architecture

The platform uses a client-side data integration approach with the following components:

1. **Data Fetching Layer**: JavaScript functions that retrieve data from external APIs
2. **Data Processing Layer**: Functions that transform API responses into the format expected by visualization components
3. **Visualization Layer**: Chart.js and custom visualization components that render the processed data

## API Integration Points

### Dashboard Data

#### Global Disruption Map
```javascript
// Example implementation for fetching global disruption data
async function fetchGlobalDisruptionData() {
  try {
    // Replace with actual API endpoint
    const response = await fetch('https://api.example.com/supply-chain/disruptions');
    const data = await response.json();
    
    // Process the data into the format expected by the map
    const processedData = data.disruptions.map(item => ({
      lat: item.latitude,
      lng: item.longitude,
      severity: item.severity,
      title: item.title,
      description: item.description,
      category: item.category
    }));
    
    return processedData;
  } catch (error) {
    console.error('Error fetching disruption data:', error);
    return []; // Return empty array as fallback
  }
}
```

#### Disruption Trend Chart
```javascript
// Example implementation for fetching trend data
async function fetchDisruptionTrendData() {
  try {
    // Replace with actual API endpoint
    const response = await fetch('https://api.example.com/supply-chain/trends?period=12m');
    const data = await response.json();
    
    // Process the data into the format expected by Chart.js
    const processedData = {
      labels: data.periods.map(period => period.label),
      datasets: [
        {
          label: 'Current Year',
          data: data.currentYear.map(value => value.count),
          backgroundColor: 'rgba(54, 162, 235, 0.2)',
          borderColor: 'rgba(54, 162, 235, 1)',
          borderWidth: 2,
          tension: 0.4
        },
        {
          label: 'Previous Year',
          data: data.previousYear.map(value => value.count),
          backgroundColor: 'rgba(153, 102, 255, 0.2)',
          borderColor: 'rgba(153, 102, 255, 1)',
          borderWidth: 2,
          tension: 0.4
        }
      ]
    };
    
    return processedData;
  } catch (error) {
    console.error('Error fetching trend data:', error);
    // Return fallback data
    return {
      labels: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      datasets: [
        {
          label: 'Current Year',
          data: [65, 78, 52, 91, 43, 58, 69, 72, 77, 0, 0, 0],
          backgroundColor: 'rgba(54, 162, 235, 0.2)',
          borderColor: 'rgba(54, 162, 235, 1)',
          borderWidth: 2,
          tension: 0.4
        }
      ]
    };
  }
}
```

### Risk Analysis Data

#### Risk Category Breakdown
```javascript
// Example implementation for fetching risk category data
async function fetchRiskCategoryData() {
  try {
    // Replace with actual API endpoint
    const response = await fetch('https://api.example.com/supply-chain/risks/categories');
    const data = await response.json();
    
    // Process the data into the format expected by Chart.js
    const processedData = {
      labels: data.categories.map(category => category.name),
      datasets: [{
        label: 'Risk Level',
        data: data.categories.map(category => category.score),
        backgroundColor: [
          'rgba(255, 99, 132, 0.7)',
          'rgba(54, 162, 235, 0.7)',
          'rgba(255, 206, 86, 0.7)',
          'rgba(75, 192, 192, 0.7)',
          'rgba(153, 102, 255, 0.7)',
          'rgba(255, 159, 64, 0.7)'
        ],
        borderWidth: 1
      }]
    };
    
    return processedData;
  } catch (error) {
    console.error('Error fetching risk category data:', error);
    // Return fallback data
    return {
      labels: ['Geopolitical', 'Environmental', 'Economic', 'Technological', 'Operational', 'Regulatory'],
      datasets: [{
        label: 'Risk Level',
        data: [85, 72, 63, 45, 56, 68],
        backgroundColor: [
          'rgba(255, 99, 132, 0.7)',
          'rgba(54, 162, 235, 0.7)',
          'rgba(255, 206, 86, 0.7)',
          'rgba(75, 192, 192, 0.7)',
          'rgba(153, 102, 255, 0.7)',
          'rgba(255, 159, 64, 0.7)'
        ],
        borderWidth: 1
      }]
    };
  }
}
```

### Industry Insights Data

#### Industry Impact Chart
```javascript
// Example implementation for fetching industry impact data
async function fetchIndustryImpactData(industry) {
  try {
    // Replace with actual API endpoint
    const response = await fetch(`https://api.example.com/supply-chain/industries/${industry}/impact`);
    const data = await response.json();
    
    // Process the data into the format expected by Chart.js
    const processedData = {
      labels: data.periods.map(period => period.label),
      datasets: [
        {
          label: 'Disruption Severity',
          data: data.metrics.severity.map(value => value.score),
          backgroundColor: 'rgba(255, 99, 132, 0.2)',
          borderColor: 'rgba(255, 99, 132, 1)',
          borderWidth: 2,
          tension: 0.4,
          yAxisID: 'y'
        },
        {
          label: 'Component Lead Time (Days)',
          data: data.metrics.leadTime.map(value => value.days),
          backgroundColor: 'rgba(54, 162, 235, 0.2)',
          borderColor: 'rgba(54, 162, 235, 1)',
          borderWidth: 2,
          tension: 0.4,
          yAxisID: 'y1'
        }
      ]
    };
    
    return processedData;
  } catch (error) {
    console.error(`Error fetching impact data for ${industry}:`, error);
    // Return fallback data
    return {
      labels: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun'],
      datasets: [
        {
          label: 'Disruption Severity',
          data: [45, 59, 80, 81, 76, 85],
          backgroundColor: 'rgba(255, 99, 132, 0.2)',
          borderColor: 'rgba(255, 99, 132, 1)',
          borderWidth: 2,
          tension: 0.4,
          yAxisID: 'y'
        },
        {
          label: 'Component Lead Time (Days)',
          data: [65, 85, 110, 125, 120, 130],
          backgroundColor: 'rgba(54, 162, 235, 0.2)',
          borderColor: 'rgba(54, 162, 235, 1)',
          borderWidth: 2,
          tension: 0.4,
          yAxisID: 'y1'
        }
      ]
    };
  }
}
```

## Recommended Data Sources

### Global Trade and Shipping Data

1. **Freightos Baltic Index API**
   - Description: Container freight rate data
   - Documentation: https://fbx.freightos.com/api/
   - Integration Priority: High

2. **Port Congestion Data API**
   - Description: Real-time port congestion metrics
   - Documentation: https://portcongestion.com/api/docs
   - Integration Priority: High

3. **Sea-Intelligence API**
   - Description: Shipping reliability and schedule data
   - Documentation: https://www.sea-intelligence.com/api
   - Integration Priority: Medium

### Risk and Disruption Data

1. **Resilinc EventWatch API**
   - Description: Supply chain disruption events
   - Documentation: https://resilinc.com/eventwatch-api/
   - Integration Priority: High

2. **DHL Resilience360 API**
   - Description: Supply chain risk monitoring
   - Documentation: https://resilience360.com/api-docs/
   - Integration Priority: Medium

3. **Everstream Analytics API**
   - Description: Predictive risk intelligence
   - Documentation: https://www.everstream.ai/api/
   - Integration Priority: Medium

### Economic and Market Data

1. **Trading Economics API**
   - Description: Economic indicators and commodity prices
   - Documentation: https://tradingeconomics.com/api/
   - Integration Priority: Medium

2. **World Bank Open Data API**
   - Description: Global economic indicators
   - Documentation: https://datahelpdesk.worldbank.org/knowledgebase/topics/125589
   - Integration Priority: Low

3. **IMF Data API**
   - Description: International trade and economic data
   - Documentation: https://www.imf.org/en/Data
   - Integration Priority: Low

## Implementation Approach

### 1. API Authentication

Most APIs require authentication. Implement a secure method to store and use API keys:

```javascript
// Example API authentication handler
class ApiAuthHandler {
  constructor() {
    // In production, these would be stored securely
    this.apiKeys = {
      'freightos': 'YOUR_FREIGHTOS_API_KEY',
      'resilinc': 'YOUR_RESILINC_API_KEY',
      'tradingeconomics': 'YOUR_TRADING_ECONOMICS_API_KEY'
    };
  }
  
  getAuthHeaders(apiName) {
    switch(apiName) {
      case 'freightos':
        return {
          'Authorization': `Bearer ${this.apiKeys.freightos}`,
          'Content-Type': 'application/json'
        };
      case 'resilinc':
        return {
          'X-API-Key': this.apiKeys.resilinc,
          'Content-Type': 'application/json'
        };
      // Add other APIs as needed
      default:
        return {
          'Content-Type': 'application/json'
        };
    }
  }
}

// Usage
const authHandler = new ApiAuthHandler();
const headers = authHandler.getAuthHeaders('freightos');
```

### 2. Data Caching

Implement caching to reduce API calls and improve performance:

```javascript
// Example caching implementation
class DataCache {
  constructor() {
    this.cache = {};
    this.expiryTimes = {};
  }
  
  set(key, data, ttlMinutes = 15) {
    this.cache[key] = data;
    this.expiryTimes[key] = Date.now() + (ttlMinutes * 60 * 1000);
  }
  
  get(key) {
    if (this.has(key)) {
      return this.cache[key];
    }
    return null;
  }
  
  has(key) {
    return this.cache.hasOwnProperty(key) && Date.now() < this.expiryTimes[key];
  }
  
  clear(key) {
    if (key) {
      delete this.cache[key];
      delete this.expiryTimes[key];
    } else {
      this.cache = {};
      this.expiryTimes = {};
    }
  }
}

// Usage
const dataCache = new DataCache();

async function getDisruptionData() {
  const cacheKey = 'global_disruptions';
  
  if (dataCache.has(cacheKey)) {
    return dataCache.get(cacheKey);
  }
  
  const data = await fetchGlobalDisruptionData();
  dataCache.set(cacheKey, data, 30); // Cache for 30 minutes
  return data;
}
```

### 3. Error Handling and Fallbacks

Implement robust error handling and fallbacks for when APIs are unavailable:

```javascript
// Example error handling with fallbacks
async function fetchDataWithFallback(primaryApiCall, fallbackApiCall, fallbackData) {
  try {
    return await primaryApiCall();
  } catch (primaryError) {
    console.error('Primary API call failed:', primaryError);
    
    try {
      return await fallbackApiCall();
    } catch (fallbackError) {
      console.error('Fallback API call failed:', fallbackError);
      return fallbackData;
    }
  }
}

// Usage
const disruptionData = await fetchDataWithFallback(
  () => fetchFromPrimaryApi('disruptions'),
  () => fetchFromSecondaryApi('disruptions'),
  DEFAULT_DISRUPTION_DATA
);
```

## Integration Testing

Before deploying API integrations to production, thoroughly test them:

1. **Unit Tests**: Test individual API fetching functions
2. **Mock Tests**: Use mock API responses to test data processing
3. **Integration Tests**: Test the full flow from API to visualization
4. **Performance Tests**: Ensure API calls don't impact page load times
5. **Error Handling Tests**: Verify fallbacks work when APIs fail

## Rate Limiting and Quotas

Most APIs have rate limits and quotas. Implement strategies to handle these constraints:

1. **Batch Requests**: Combine multiple data needs into fewer API calls
2. **Staggered Loading**: Load critical data first, then less important data
3. **Background Refreshing**: Update data in the background while users interact with the page
4. **Adaptive Polling**: Adjust polling frequency based on user activity and data volatility

## Security Considerations

When integrating with external APIs, consider these security practices:

1. **Never expose API keys in client-side code** - Use a backend proxy if necessary
2. **Validate all API responses** before processing them
3. **Implement CORS policies** to prevent unauthorized API access
4. **Use HTTPS** for all API communications
5. **Sanitize data** before displaying it to prevent XSS attacks

## Conclusion

This guide provides a framework for integrating real data sources with the SupplyChain Pulse platform. By following these patterns and best practices, you can replace the simulated data with live information from authoritative sources.

For specific API integration assistance, contact the development team.
