// Dashboard specific JavaScript functionality
// This file handles the data visualization and interactivity for the dashboard page

document.addEventListener('DOMContentLoaded', function() {
    // Initialize dashboard-specific charts and visualizations
    initDashboardCharts();
    
    // Initialize dashboard filters
    initDashboardFilters();
    
    // Initialize real-time data updates
    initRealTimeUpdates();
    
    // Initialize dashboard alerts
    initDashboardAlerts();
});

// Initialize dashboard charts
function initDashboardCharts() {
    // Disruption trend chart
    initDisruptionTrendChart();
    
    // Regional impact chart
    initRegionalImpactChart();
    
    // Industry vulnerability chart
    initIndustryVulnerabilityChart();
    
    // Commodity price impact chart
    initCommodityPriceChart();
}

// Disruption trend chart - shows trends over time
function initDisruptionTrendChart() {
    const trendChartElement = document.getElementById('disruption-trend-chart');
    
    if (!trendChartElement) return;
    
    // Sample data - in a real implementation, this would come from an API
    const trendData = {
        labels: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
        datasets: [
            {
                label: '2024',
                data: [42, 55, 49, 58, 63, 51, 47, 53, 60, 65, 59, 68],
                backgroundColor: 'rgba(153, 102, 255, 0.2)',
                borderColor: 'rgba(153, 102, 255, 1)',
                borderWidth: 2,
                tension: 0.4
            },
            {
                label: '2025',
                data: [65, 78, 52, 91, 43, 58, 69, 72, 77, null, null, null], // Null for future months
                backgroundColor: 'rgba(54, 162, 235, 0.2)',
                borderColor: 'rgba(54, 162, 235, 1)',
                borderWidth: 2,
                tension: 0.4
            }
        ]
    };
    
    new Chart(trendChartElement, {
        type: 'line',
        data: trendData,
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: {
                    position: 'top',
                },
                tooltip: {
                    mode: 'index',
                    intersect: false,
                }
            },
            scales: {
                y: {
                    beginAtZero: true,
                    title: {
                        display: true,
                        text: 'Disruption Index'
                    }
                }
            }
        }
    });
}

// Regional impact chart - shows impact by region
function initRegionalImpactChart() {
    const regionalChartElement = document.getElementById('regional-impact-chart');
    
    if (!regionalChartElement) return;
    
    // Sample data - in a real implementation, this would come from an API
    const regionalData = {
        labels: ['North America', 'Europe', 'Asia Pacific', 'Latin America', 'Middle East', 'Africa'],
        datasets: [{
            label: 'Current Disruption Level',
            data: [65, 78, 92, 56, 84, 43],
            backgroundColor: [
                'rgba(255, 99, 132, 0.7)',
                'rgba(54, 162, 235, 0.7)',
                'rgba(255, 206, 86, 0.7)',
                'rgba(75, 192, 192, 0.7)',
                'rgba(153, 102, 255, 0.7)',
                'rgba(255, 159, 64, 0.7)'
            ],
            borderWidth: 1
        }]
    };
    
    new Chart(regionalChartElement, {
        type: 'polarArea',
        data: regionalData,
        options: {
            responsive: true,
            maintainAspectRatio: false,
            scales: {
                r: {
                    beginAtZero: true,
                    max: 100
                }
            },
            plugins: {
                legend: {
                    position: 'right',
                }
            }
        }
    });
}

// Industry vulnerability chart - shows vulnerability by industry
function initIndustryVulnerabilityChart() {
    const industryChartElement = document.getElementById('industry-vulnerability-chart');
    
    if (!industryChartElement) return;
    
    // Sample data - in a real implementation, this would come from an API
    const industryData = {
        labels: ['Electronics', 'Automotive', 'Pharmaceuticals', 'Food & Beverage', 'Retail', 'Energy', 'Manufacturing'],
        datasets: [{
            label: 'Vulnerability Score',
            data: [85, 72, 65, 53, 68, 76, 79],
            backgroundColor: 'rgba(54, 162, 235, 0.5)',
            borderColor: 'rgba(54, 162, 235, 1)',
            borderWidth: 1
        }]
    };
    
    new Chart(industryChartElement, {
        type: 'bar',
        data: industryData,
        options: {
            indexAxis: 'y',
            responsive: true,
            maintainAspectRatio: false,
            scales: {
                x: {
                    beginAtZero: true,
                    max: 100,
                    title: {
                        display: true,
                        text: 'Vulnerability Score'
                    }
                }
            }
        }
    });
}

// Commodity price impact chart - shows price trends for key commodities
function initCommodityPriceChart() {
    const commodityChartElement = document.getElementById('commodity-price-chart');
    
    if (!commodityChartElement) return;
    
    // Sample data - in a real implementation, this would come from an API
    const commodityData = {
        labels: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct'],
        datasets: [
            {
                label: 'Semiconductors',
                data: [100, 105, 115, 125, 130, 128, 135, 142, 138, 145],
                borderColor: 'rgba(255, 99, 132, 1)',
                backgroundColor: 'rgba(255, 99, 132, 0.1)',
                borderWidth: 2,
                fill: true,
                tension: 0.4
            },
            {
                label: 'Rare Earth Metals',
                data: [100, 102, 108, 112, 118, 125, 130, 135, 142, 148],
                borderColor: 'rgba(54, 162, 235, 1)',
                backgroundColor: 'rgba(54, 162, 235, 0.1)',
                borderWidth: 2,
                fill: true,
                tension: 0.4
            },
            {
                label: 'Lithium',
                data: [100, 110, 118, 125, 135, 142, 138, 145, 152, 158],
                borderColor: 'rgba(255, 206, 86, 1)',
                backgroundColor: 'rgba(255, 206, 86, 0.1)',
                borderWidth: 2,
                fill: true,
                tension: 0.4
            }
        ]
    };
    
    new Chart(commodityChartElement, {
        type: 'line',
        data: commodityData,
        options: {
            responsive: true,
            maintainAspectRatio: false,
            scales: {
                y: {
                    title: {
                        display: true,
                        text: 'Price Index (Jan 2025 = 100)'
                    }
                }
            },
            plugins: {
                legend: {
                    position: 'top',
                },
                tooltip: {
                    mode: 'index',
                    intersect: false
                }
            }
        }
    });
}

// Initialize dashboard filters
function initDashboardFilters() {
    const industryFilter = document.getElementById('industry-filter');
    const regionFilter = document.getElementById('region-filter');
    const timeRangeFilter = document.getElementById('time-range-filter');
    const applyFiltersBtn = document.getElementById('apply-filters');
    
    if (applyFiltersBtn) {
        applyFiltersBtn.addEventListener('click', function() {
            // In a real implementation, this would fetch new data based on filters
            // For this demo, we'll just show a loading indicator and then refresh the page
            const dashboardContent = document.querySelector('.dashboard-content');
            
            if (dashboardContent) {
                // Add loading overlay
                const loadingOverlay = document.createElement('div');
                loadingOverlay.className = 'loading-overlay';
                loadingOverlay.innerHTML = '<div class="loading-spinner"></div><p>Updating dashboard...</p>';
                dashboardContent.appendChild(loadingOverlay);
                
                // Simulate loading delay
                setTimeout(() => {
                    // Remove loading overlay
                    loadingOverlay.remove();
                    
                    // Show filter applied message
                    const filterMessage = document.createElement('div');
                    filterMessage.className = 'filter-applied-message';
                    filterMessage.textContent = 'Filters applied successfully!';
                    dashboardContent.appendChild(filterMessage);
                    
                    // Remove message after 3 seconds
                    setTimeout(() => {
                        filterMessage.remove();
                    }, 3000);
                    
                    // Update charts with "filtered" data (in reality, just random variations)
                    updateChartsWithFilteredData();
                }, 1500);
            }
        });
    }
    
    // Reset filters button
    const resetFiltersBtn = document.getElementById('reset-filters');
    
    if (resetFiltersBtn) {
        resetFiltersBtn.addEventListener('click', function() {
            // Reset filter selections
            if (industryFilter) industryFilter.value = 'all';
            if (regionFilter) regionFilter.value = 'all';
            if (timeRangeFilter) timeRangeFilter.value = '6m';
            
            // In a real implementation, this would reset the dashboard data
            // For this demo, we'll just show a message
            const dashboardContent = document.querySelector('.dashboard-content');
            
            if (dashboardContent) {
                const resetMessage = document.createElement('div');
                resetMessage.className = 'filter-reset-message';
                resetMessage.textContent = 'Filters have been reset.';
                dashboardContent.appendChild(resetMessage);
                
                // Remove message after 3 seconds
                setTimeout(() => {
                    resetMessage.remove();
                }, 3000);
            }
        });
    }
}

// Update charts with "filtered" data
function updateChartsWithFilteredData() {
    // In a real implementation, this would use actual filtered data
    // For this demo, we'll just make random variations to the existing charts
    
    // Get all chart instances
    const charts = Object.values(Chart.instances);
    
    charts.forEach(chart => {
        // Apply random variations to each dataset
        chart.data.datasets.forEach(dataset => {
            dataset.data = dataset.data.map(value => {
                if (value === null) return null; // Preserve null values
                // Random variation between -10% and +10%
                const variation = 1 + (Math.random() * 0.2 - 0.1);
                return Math.round(value * variation);
            });
        });
        
        // Update the chart
        chart.update();
    });
}

// Initialize real-time data updates
function initRealTimeUpdates() {
    // Update the last updated timestamp
    updateLastUpdatedTime();
    
    // Update disruption counters
    updateDisruptionCounters();
    
    // Set up interval for real-time updates
    setInterval(() => {
        updateLastUpdatedTime();
        updateDisruptionCounters();
        updateAlertFeed();
    }, 60000); // Update every minute
}

// Update the last updated timestamp
function updateLastUpdatedTime() {
    const lastUpdatedElement = document.getElementById('last-updated-time');
    
    if (lastUpdatedElement) {
        const now = new Date();
        const formattedTime = now.toLocaleTimeString([], { hour: '2-digit', minute: '2-digit' });
        lastUpdatedElement.textContent = formattedTime;
    }
}

// Update disruption counters with simulated data
function updateDisruptionCounters() {
    const activeDisruptions = document.getElementById('active-disruptions-count');
    const highRiskRegions = document.getElementById('high-risk-regions-count');
    const affectedIndustries = document.getElementById('affected-industries-count');
    
    if (activeDisruptions) {
        // Simulate random fluctuation in active disruptions
        const currentValue = parseInt(activeDisruptions.textContent);
        const newValue = currentValue + Math.floor(Math.random() * 5) - 2; // Random change between -2 and +2
        activeDisruptions.textContent = Math.max(0, newValue);
    }
    
    if (highRiskRegions) {
        // Simulate occasional changes in high risk regions
        if (Math.random() > 0.7) { // 30% chance of change
            const currentValue = parseInt(highRiskRegions.textContent);
            const newValue = currentValue + (Math.random() > 0.5 ? 1 : -1); // Increase or decrease by 1
            highRiskRegions.textContent = Math.max(0, Math.min(7, newValue)); // Keep between 0 and 7
        }
    }
    
    if (affectedIndustries) {
        // Simulate occasional changes in affected industries
        if (Math.random() > 0.8) { // 20% chance of change
            const currentValue = parseInt(affectedIndustries.textContent);
            const newValue = currentValue + (Math.random() > 0.5 ? 1 : -1); // Increase or decrease by 1
            affectedIndustries.textContent = Math.max(0, Math.min(12, newValue)); // Keep between 0 and 12
        }
    }
}

// Initialize dashboard alerts
function initDashboardAlerts() {
    // Initial alert feed
    updateAlertFeed();
    
    // Set up alert filter functionality
    const alertFilters = document.querySelectorAll('.alert-filter-btn');
    
    if (alertFilters.length > 0) {
        alertFilters.forEach(filter => {
            filter.addEventListener('click', function() {
                // Remove active class from all filters
                alertFilters.forEach(f => f.classList.remove('active'));
                
                // Add active class to clicked filter
                this.classList.add('active');
                
                // Filter alerts based on selected category
                const category = this.getAttribute('data-category');
                const alertItems = document.querySelectorAll('.alert-item');
                
                alertItems.forEach(alert => {
                    if (category === 'all' || alert.getAttribute('data-category') === category) {
                        alert.style.display = 'flex';
                    } else {
                        alert.style.display = 'none';
                    }
                });
            });
        });
    }
}

// Update alert feed with new alerts
function updateAlertFeed() {
    const alertFeed = document.querySelector('.alert-feed');
    
    if (!alertFeed) return;
    
    // 20% chance of adding a new alert
    if (Math.random() > 0.8) {
        // Sample alert data
        const alertTypes = ['disruption', 'geopolitical', 'economic', 'weather'];
        const alertSeverities = ['low', 'medium', 'high', 'critical'];
        const alertTitles = [
            'Port congestion reported in Singapore',
            'Trade tensions escalate between major economies',
            'Semiconductor factory shutdown in Taiwan',
            'Severe weather affecting shipping routes in Atlantic',
            'Labor strikes at major logistics hubs in Europe',
            'Regulatory changes impacting cross-border trade',
            'Cybersecurity incident affecting supply chain systems',
            'Raw material shortages reported for key components'
        ];
        
        // Generate random alert
        const randomType = alertTypes[Math.floor(Math.random() * alertTypes.length)];
        const randomSeverity = alertSeverities[Math.floor(Math.random() * alertSeverities.length)];
        const randomTitle = alertTitles[Math.floor(Math.random() * alertTitles.length)];
        
        // Create new alert element
        const newAlert = document.createElement('div');
        newAlert.className = 'alert-item';
        newAlert.setAttribute('data-category', randomType);
        
        // Format current time
        const now = new Date();
        const formattedTime = now.toLocaleTimeString([], { hour: '2-digit', minute: '2-digit' });
        
        // Set alert content
        newAlert.innerHTML = `
            <div class="alert-severity ${randomSeverity}"></div>
            <div class="alert-content">
                <div class="alert-header">
                    <span class="alert-type">${randomType.charAt(0).toUpperCase() + randomType.slice(1)}</span>
                    <span class="alert-time">${formattedTime}</span>
                </div>
                <h4 class="alert-title">${randomTitle}</h4>
                <a href="#" class="alert-link">View Details</a>
            </div>
        `;
        
        // Add new alert to the beginning of the feed
        alertFeed.insertBefore(newAlert, alertFeed.firstChild);
        
        // Remove oldest alert if there are more than 10
        const alertItems = alertFeed.querySelectorAll('.alert-item');
        if (alertItems.length > 10) {
            alertFeed.removeChild(alertItems[alertItems.length - 1]);
        }
        
        // Highlight new alert
        newAlert.classList.add('new-alert');
        setTimeout(() => {
            newAlert.classList.remove('new-alert');
        }, 3000);
    }
}
