// Main JavaScript file for data visualization and integration
// This file handles the core functionality for the SupplyChain Pulse website

// Wait for DOM to be fully loaded
document.addEventListener('DOMContentLoaded', function() {
    // Initialize mobile menu functionality
    initMobileMenu();
    
    // Initialize any charts that exist on the current page
    initCharts();
    
    // Initialize interactive maps if they exist on the page
    initMaps();
    
    // Set up form validation for any forms on the page
    initFormValidation();
    
    // Initialize FAQ accordions if they exist
    initFaqAccordions();
    
    // Initialize testimonial sliders if they exist
    initTestimonialSliders();
    
    // Initialize tab navigation if it exists
    initTabNavigation();
});

// Mobile menu toggle functionality
function initMobileMenu() {
    const menuToggle = document.querySelector('.mobile-menu-toggle');
    const navList = document.querySelector('.nav-list');
    
    if (menuToggle && navList) {
        menuToggle.addEventListener('click', function() {
            navList.classList.toggle('active');
            menuToggle.classList.toggle('active');
        });
    }
}

// Initialize charts using Chart.js
function initCharts() {
    // Check if Chart.js is available
    if (typeof Chart === 'undefined') {
        console.warn('Chart.js is not loaded. Charts will not be rendered.');
        return;
    }
    
    // Initialize dashboard overview chart if it exists
    initDashboardOverviewChart();
    
    // Initialize risk analysis charts if they exist
    initRiskAnalysisCharts();
    
    // Initialize industry impact charts if they exist
    initIndustryImpactCharts();
}

// Dashboard overview chart
function initDashboardOverviewChart() {
    const overviewChartElement = document.getElementById('disruption-overview-chart');
    
    if (!overviewChartElement) return;
    
    // Sample data - in a real implementation, this would come from an API
    const disruptionData = {
        labels: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun'],
        datasets: [
            {
                label: 'Supply Chain Disruptions',
                data: [65, 78, 52, 91, 43, 58],
                backgroundColor: 'rgba(54, 162, 235, 0.2)',
                borderColor: 'rgba(54, 162, 235, 1)',
                borderWidth: 2,
                tension: 0.4
            },
            {
                label: 'Trade Tensions',
                data: [28, 48, 40, 19, 86, 27],
                backgroundColor: 'rgba(255, 99, 132, 0.2)',
                borderColor: 'rgba(255, 99, 132, 1)',
                borderWidth: 2,
                tension: 0.4
            }
        ]
    };
    
    new Chart(overviewChartElement, {
        type: 'line',
        data: disruptionData,
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: {
                    position: 'top',
                },
                tooltip: {
                    mode: 'index',
                    intersect: false,
                }
            },
            scales: {
                y: {
                    beginAtZero: true,
                    title: {
                        display: true,
                        text: 'Number of Incidents'
                    }
                },
                x: {
                    title: {
                        display: true,
                        text: '2025'
                    }
                }
            }
        }
    });
}

// Risk analysis charts
function initRiskAnalysisCharts() {
    // Risk by category chart
    const riskCategoryElement = document.getElementById('risk-category-chart');
    
    if (riskCategoryElement) {
        // Sample data - in a real implementation, this would come from an API
        const riskCategoryData = {
            labels: ['Geopolitical', 'Environmental', 'Economic', 'Technological', 'Operational', 'Regulatory'],
            datasets: [{
                label: 'Risk Level',
                data: [85, 72, 63, 45, 56, 68],
                backgroundColor: [
                    'rgba(255, 99, 132, 0.7)',
                    'rgba(54, 162, 235, 0.7)',
                    'rgba(255, 206, 86, 0.7)',
                    'rgba(75, 192, 192, 0.7)',
                    'rgba(153, 102, 255, 0.7)',
                    'rgba(255, 159, 64, 0.7)'
                ],
                borderWidth: 1
            }]
        };
        
        new Chart(riskCategoryElement, {
            type: 'radar',
            data: riskCategoryData,
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    r: {
                        beginAtZero: true,
                        max: 100,
                        ticks: {
                            stepSize: 20
                        }
                    }
                }
            }
        });
    }
    
    // Regional risk heatmap
    const regionalRiskElement = document.getElementById('regional-risk-chart');
    
    if (regionalRiskElement) {
        // Sample data - in a real implementation, this would come from an API
        const regionalRiskData = {
            labels: ['North America', 'South America', 'Europe', 'Middle East', 'Asia', 'Africa', 'Oceania'],
            datasets: [{
                label: 'Current Risk Level',
                data: [45, 59, 68, 81, 76, 63, 42],
                backgroundColor: 'rgba(255, 99, 132, 0.7)',
                borderColor: 'rgba(255, 99, 132, 1)',
                borderWidth: 1
            },
            {
                label: 'Previous Quarter',
                data: [38, 53, 65, 84, 71, 59, 40],
                backgroundColor: 'rgba(54, 162, 235, 0.7)',
                borderColor: 'rgba(54, 162, 235, 1)',
                borderWidth: 1
            }]
        };
        
        new Chart(regionalRiskElement, {
            type: 'bar',
            data: regionalRiskData,
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        max: 100,
                        title: {
                            display: true,
                            text: 'Risk Score'
                        }
                    }
                },
                plugins: {
                    legend: {
                        position: 'top',
                    }
                }
            }
        });
    }
}

// Industry impact charts
function initIndustryImpactCharts() {
    const electronicsImpactElement = document.getElementById('electronics-impact-chart');
    
    if (electronicsImpactElement) {
        // Sample data - in a real implementation, this would come from an API
        const impactData = {
            labels: ['Oct', 'Nov', 'Dec', 'Jan', 'Feb', 'Mar'],
            datasets: [
                {
                    label: 'Disruption Severity',
                    data: [45, 59, 80, 81, 76, 85],
                    backgroundColor: 'rgba(255, 99, 132, 0.2)',
                    borderColor: 'rgba(255, 99, 132, 1)',
                    borderWidth: 2,
                    tension: 0.4,
                    yAxisID: 'y'
                },
                {
                    label: 'Component Lead Time (Days)',
                    data: [65, 85, 110, 125, 120, 130],
                    backgroundColor: 'rgba(54, 162, 235, 0.2)',
                    borderColor: 'rgba(54, 162, 235, 1)',
                    borderWidth: 2,
                    tension: 0.4,
                    yAxisID: 'y1'
                }
            ]
        };
        
        new Chart(electronicsImpactElement, {
            type: 'line',
            data: impactData,
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        type: 'linear',
                        display: true,
                        position: 'left',
                        title: {
                            display: true,
                            text: 'Disruption Severity (0-100)'
                        },
                        max: 100
                    },
                    y1: {
                        type: 'linear',
                        display: true,
                        position: 'right',
                        title: {
                            display: true,
                            text: 'Lead Time (Days)'
                        },
                        grid: {
                            drawOnChartArea: false
                        }
                    }
                },
                plugins: {
                    legend: {
                        position: 'top',
                    },
                    tooltip: {
                        mode: 'index',
                        intersect: false
                    }
                }
            }
        });
    }
}

// Initialize interactive maps
function initMaps() {
    // Check if the global disruption map element exists
    const globalMapElement = document.getElementById('global-disruption-map');
    
    if (globalMapElement) {
        // In a real implementation, we would use a mapping library like Leaflet or Mapbox
        // For this demo, we'll just add a placeholder message
        globalMapElement.innerHTML = '<div class="map-placeholder"><p>Interactive global disruption map would be rendered here using Leaflet or Mapbox.</p><p>The map would display real-time supply chain disruptions across the world with severity indicators and filtering options.</p></div>';
        
        // Add a class to style the placeholder
        globalMapElement.classList.add('map-initialized');
    }
    
    // Check if the trade flow map element exists
    const tradeFlowElement = document.getElementById('trade-flow-map');
    
    if (tradeFlowElement) {
        // In a real implementation, we would use a mapping library like Leaflet or Mapbox
        // For this demo, we'll just add a placeholder message
        tradeFlowElement.innerHTML = '<div class="map-placeholder"><p>Interactive trade flow map would be rendered here using D3.js or a similar visualization library.</p><p>The map would display global trade flows with animated paths showing volume and direction.</p></div>';
        
        // Add a class to style the placeholder
        tradeFlowElement.classList.add('map-initialized');
    }
}

// Form validation
function initFormValidation() {
    const forms = document.querySelectorAll('form');
    
    forms.forEach(form => {
        form.addEventListener('submit', function(event) {
            event.preventDefault();
            
            // Basic validation
            let isValid = true;
            const requiredFields = form.querySelectorAll('[required]');
            
            requiredFields.forEach(field => {
                if (!field.value.trim()) {
                    isValid = false;
                    field.classList.add('error');
                    
                    // Add error message if it doesn't exist
                    let errorMessage = field.parentNode.querySelector('.error-message');
                    if (!errorMessage) {
                        errorMessage = document.createElement('span');
                        errorMessage.className = 'error-message';
                        errorMessage.textContent = 'This field is required';
                        field.parentNode.appendChild(errorMessage);
                    }
                } else {
                    field.classList.remove('error');
                    const errorMessage = field.parentNode.querySelector('.error-message');
                    if (errorMessage) {
                        errorMessage.remove();
                    }
                }
            });
            
            // Email validation for email fields
            const emailFields = form.querySelectorAll('input[type="email"]');
            emailFields.forEach(field => {
                if (field.value.trim() && !validateEmail(field.value)) {
                    isValid = false;
                    field.classList.add('error');
                    
                    // Add error message if it doesn't exist
                    let errorMessage = field.parentNode.querySelector('.error-message');
                    if (!errorMessage) {
                        errorMessage = document.createElement('span');
                        errorMessage.className = 'error-message';
                        errorMessage.textContent = 'Please enter a valid email address';
                        field.parentNode.appendChild(errorMessage);
                    } else {
                        errorMessage.textContent = 'Please enter a valid email address';
                    }
                }
            });
            
            // If form is valid, show success message
            if (isValid) {
                // In a real implementation, we would submit the form data to a server
                // For this demo, we'll just show a success message
                const successMessage = document.createElement('div');
                successMessage.className = 'form-success-message';
                successMessage.textContent = 'Form submitted successfully! We will get back to you soon.';
                
                // Insert the success message after the form
                form.parentNode.insertBefore(successMessage, form.nextSibling);
                
                // Reset the form
                form.reset();
                
                // Remove the success message after 5 seconds
                setTimeout(() => {
                    successMessage.remove();
                }, 5000);
            }
        });
        
        // Remove error styling when user starts typing
        const formFields = form.querySelectorAll('input, textarea, select');
        formFields.forEach(field => {
            field.addEventListener('input', function() {
                field.classList.remove('error');
                const errorMessage = field.parentNode.querySelector('.error-message');
                if (errorMessage) {
                    errorMessage.remove();
                }
            });
        });
    });
}

// Email validation helper function
function validateEmail(email) {
    const re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    return re.test(String(email).toLowerCase());
}

// Initialize FAQ accordions
function initFaqAccordions() {
    const faqItems = document.querySelectorAll('.faq-item');
    
    faqItems.forEach(item => {
        const question = item.querySelector('.faq-question');
        const answer = item.querySelector('.faq-answer');
        const toggle = item.querySelector('.faq-toggle');
        
        if (question && answer && toggle) {
            // Initially hide all answers
            answer.style.display = 'none';
            
            question.addEventListener('click', function() {
                // Toggle the answer visibility
                if (answer.style.display === 'none') {
                    answer.style.display = 'block';
                    toggle.innerHTML = '<i class="fas fa-minus"></i>';
                    item.classList.add('active');
                } else {
                    answer.style.display = 'none';
                    toggle.innerHTML = '<i class="fas fa-plus"></i>';
                    item.classList.remove('active');
                }
            });
        }
    });
}

// Initialize testimonial sliders
function initTestimonialSliders() {
    const sliders = document.querySelectorAll('.testimonial-slider');
    
    sliders.forEach(slider => {
        const testimonials = slider.querySelectorAll('.testimonial');
        const dots = slider.parentNode.querySelectorAll('.dot');
        const prevButton = slider.parentNode.querySelector('.slider-prev');
        const nextButton = slider.parentNode.querySelector('.slider-next');
        
        if (testimonials.length > 0) {
            let currentIndex = 0;
            
            // Show the first testimonial, hide the rest
            testimonials.forEach((testimonial, index) => {
                if (index === 0) {
                    testimonial.style.display = 'block';
                } else {
                    testimonial.style.display = 'none';
                }
            });
            
            // Previous button functionality
            if (prevButton) {
                prevButton.addEventListener('click', function() {
                    testimonials[currentIndex].style.display = 'none';
                    dots[currentIndex].classList.remove('active');
                    
                    currentIndex = (currentIndex - 1 + testimonials.length) % testimonials.length;
                    
                    testimonials[currentIndex].style.display = 'block';
                    dots[currentIndex].classList.add('active');
                });
            }
            
            // Next button functionality
            if (nextButton) {
                nextButton.addEventListener('click', function() {
                    testimonials[currentIndex].style.display = 'none';
                    dots[currentIndex].classList.remove('active');
                    
                    currentIndex = (currentIndex + 1) % testimonials.length;
                    
                    testimonials[currentIndex].style.display = 'block';
                    dots[currentIndex].classList.add('active');
                });
            }
            
            // Dot navigation
            dots.forEach((dot, index) => {
                dot.addEventListener('click', function() {
                    testimonials[currentIndex].style.display = 'none';
                    dots[currentIndex].classList.remove('active');
                    
                    currentIndex = index;
                    
                    testimonials[currentIndex].style.display = 'block';
                    dots[currentIndex].classList.add('active');
                });
            });
        }
    });
}

// Initialize tab navigation
function initTabNavigation() {
    // Industry impact tabs
    const impactTabs = document.querySelectorAll('.impact-tabs .tab-button');
    
    if (impactTabs.length > 0) {
        impactTabs.forEach(tab => {
            tab.addEventListener('click', function() {
                // Remove active class from all tabs
                impactTabs.forEach(t => t.classList.remove('active'));
                
                // Add active class to clicked tab
                this.classList.add('active');
                
                // Hide all tab panes
                const tabPanes = document.querySelectorAll('.impact-tabs .tab-pane');
                tabPanes.forEach(pane => pane.classList.remove('active'));
                
                // Show the selected tab pane
                const tabId = this.getAttribute('data-tab');
                const selectedPane = document.getElementById(tabId + '-impact');
                if (selectedPane) {
                    selectedPane.classList.add('active');
                }
            });
        });
    }
    
    // Resource category tabs
    const categoryTabs = document.querySelectorAll('.category-tab');
    
    if (categoryTabs.length > 0) {
        categoryTabs.forEach(tab => {
            tab.addEventListener('click', function() {
                // Remove active class from all tabs
                categoryTabs.forEach(t => t.classList.remove('active'));
                
                // Add active class to clicked tab
                this.classList.add('active');
                
                // Filter resources based on selected category
                const category = this.getAttribute('data-category');
                const resourceCards = document.querySelectorAll('.resource-card');
                
                resourceCards.forEach(card => {
                    if (category === 'all' || card.classList.contains(category)) {
                        card.style.display = 'flex';
                    } else {
                        card.style.display = 'none';
                    }
                });
            });
        });
    }
}

// Function to fetch and display real-time data
// In a real implementation, this would connect to an API
function fetchRealTimeData() {
    // Simulate API call with setTimeout
    setTimeout(() => {
        // Update disruption counters
        updateDisruptionCounters();
        
        // Update risk levels
        updateRiskLevels();
        
        // Schedule next update
        setTimeout(fetchRealTimeData, 60000); // Update every minute
    }, 1000);
}

// Update disruption counters with simulated data
function updateDisruptionCounters() {
    const activeDisruptions = document.getElementById('active-disruptions-count');
    const highRiskRegions = document.getElementById('high-risk-regions-count');
    const affectedIndustries = document.getElementById('affected-industries-count');
    
    if (activeDisruptions) {
        // Simulate random fluctuation in active disruptions
        const currentValue = parseInt(activeDisruptions.textContent);
        const newValue = currentValue + Math.floor(Math.random() * 5) - 2; // Random change between -2 and +2
        activeDisruptions.textContent = Math.max(0, newValue);
    }
    
    if (highRiskRegions) {
        // Simulate occasional changes in high risk regions
        if (Math.random() > 0.7) { // 30% chance of change
            const currentValue = parseInt(highRiskRegions.textContent);
            const newValue = currentValue + (Math.random() > 0.5 ? 1 : -1); // Increase or decrease by 1
            highRiskRegions.textContent = Math.max(0, Math.min(7, newValue)); // Keep between 0 and 7
        }
    }
    
    if (affectedIndustries) {
        // Simulate occasional changes in affected industries
        if (Math.random() > 0.8) { // 20% chance of change
            const currentValue = parseInt(affectedIndustries.textContent);
            const newValue = currentValue + (Math.random() > 0.5 ? 1 : -1); // Increase or decrease by 1
            affectedIndustries.textContent = Math.max(0, Math.min(12, newValue)); // Keep between 0 and 12
        }
    }
}

// Update risk levels with simulated data
function updateRiskLevels() {
    const riskIndicators = document.querySelectorAll('.risk-indicator');
    
    riskIndicators.forEach(indicator => {
        // Get current risk level
        const riskLevel = indicator.getAttribute('data-risk-level');
        
        // 10% chance of changing risk level
        if (Math.random() > 0.9) {
            const levels = ['low', 'medium', 'high', 'critical'];
            const currentIndex = levels.indexOf(riskLevel);
            
            // Randomly move up or down one level, but stay within bounds
            let newIndex;
            if (currentIndex === 0) {
                newIndex = Math.random() > 0.7 ? 1 : 0; // More likely to stay low
            } else if (currentIndex === levels.length - 1) {
                newIndex = Math.random() > 0.7 ? currentIndex - 1 : currentIndex; // More likely to decrease from critical
            } else {
                newIndex = currentIndex + (Math.random() > 0.5 ? 1 : -1); // Random up or down
            }
            
            // Update the risk level
            const newLevel = levels[newIndex];
            indicator.setAttribute('data-risk-level', newLevel);
            indicator.className = 'risk-indicator ' + newLevel;
            
            // Update the text if it exists
            const riskText = indicator.querySelector('.risk-text');
            if (riskText) {
                riskText.textContent = newLevel.charAt(0).toUpperCase() + newLevel.slice(1);
            }
        }
    });
}

// Start fetching real-time data if we're on a page that needs it
if (document.querySelector('.dashboard-section') || document.querySelector('.risk-analysis-section')) {
    fetchRealTimeData();
}
