// Risk Analysis specific JavaScript functionality
// This file handles the data visualization and interactivity for the risk analysis page

document.addEventListener('DOMContentLoaded', function() {
    // Initialize risk analysis charts and visualizations
    initRiskAnalysisCharts();
    
    // Initialize risk filters
    initRiskFilters();
    
    // Initialize risk comparison tools
    initRiskComparison();
    
    // Initialize risk timeline
    initRiskTimeline();
    
    // Initialize risk factor analysis
    initRiskFactorAnalysis();
});

// Initialize risk analysis charts
function initRiskAnalysisCharts() {
    // Global risk heatmap
    initGlobalRiskHeatmap();
    
    // Risk category breakdown
    initRiskCategoryBreakdown();
    
    // Risk trend analysis
    initRiskTrendAnalysis();
    
    // Risk impact vs probability matrix
    initRiskMatrix();
}

// Global risk heatmap - shows risk levels across regions
function initGlobalRiskHeatmap() {
    const heatmapElement = document.getElementById('global-risk-heatmap');
    
    if (!heatmapElement) return;
    
    // In a real implementation, this would use a mapping library like Leaflet or Mapbox
    // For this demo, we'll create a placeholder with a message about the visualization
    heatmapElement.innerHTML = `
        <div class="map-placeholder">
            <h3>Global Risk Heatmap</h3>
            <p>This interactive map would display risk levels across different regions using color coding.</p>
            <p>Users would be able to hover over regions to see detailed risk metrics and click for in-depth analysis.</p>
            <div class="map-legend">
                <div class="legend-item">
                    <span class="legend-color" style="background-color: #ffcccc;"></span>
                    <span class="legend-label">Low Risk</span>
                </div>
                <div class="legend-item">
                    <span class="legend-color" style="background-color: #ff9999;"></span>
                    <span class="legend-label">Medium Risk</span>
                </div>
                <div class="legend-item">
                    <span class="legend-color" style="background-color: #ff6666;"></span>
                    <span class="legend-label">High Risk</span>
                </div>
                <div class="legend-item">
                    <span class="legend-color" style="background-color: #ff0000;"></span>
                    <span class="legend-label">Critical Risk</span>
                </div>
            </div>
        </div>
    `;
}

// Risk category breakdown - shows risk levels by category
function initRiskCategoryBreakdown() {
    const categoryChartElement = document.getElementById('risk-category-chart');
    
    if (!categoryChartElement) return;
    
    // Sample data - in a real implementation, this would come from an API
    const categoryData = {
        labels: ['Geopolitical', 'Environmental', 'Economic', 'Technological', 'Operational', 'Regulatory'],
        datasets: [{
            label: 'Current Risk Level',
            data: [85, 72, 63, 45, 56, 68],
            backgroundColor: [
                'rgba(255, 99, 132, 0.7)',
                'rgba(54, 162, 235, 0.7)',
                'rgba(255, 206, 86, 0.7)',
                'rgba(75, 192, 192, 0.7)',
                'rgba(153, 102, 255, 0.7)',
                'rgba(255, 159, 64, 0.7)'
            ],
            borderWidth: 1
        }]
    };
    
    new Chart(categoryChartElement, {
        type: 'radar',
        data: categoryData,
        options: {
            responsive: true,
            maintainAspectRatio: false,
            scales: {
                r: {
                    beginAtZero: true,
                    max: 100,
                    ticks: {
                        stepSize: 20
                    }
                }
            }
        }
    });
}

// Risk trend analysis - shows how risk levels have changed over time
function initRiskTrendAnalysis() {
    const trendChartElement = document.getElementById('risk-trend-chart');
    
    if (!trendChartElement) return;
    
    // Sample data - in a real implementation, this would come from an API
    const trendData = {
        labels: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct'],
        datasets: [
            {
                label: 'Geopolitical Risk',
                data: [65, 68, 75, 81, 85, 83, 78, 75, 82, 85],
                borderColor: 'rgba(255, 99, 132, 1)',
                backgroundColor: 'rgba(255, 99, 132, 0.1)',
                borderWidth: 2,
                fill: true,
                tension: 0.4
            },
            {
                label: 'Environmental Risk',
                data: [55, 58, 62, 65, 72, 78, 75, 70, 68, 72],
                borderColor: 'rgba(54, 162, 235, 1)',
                backgroundColor: 'rgba(54, 162, 235, 0.1)',
                borderWidth: 2,
                fill: true,
                tension: 0.4
            },
            {
                label: 'Economic Risk',
                data: [70, 68, 65, 60, 58, 62, 65, 68, 63, 63],
                borderColor: 'rgba(255, 206, 86, 1)',
                backgroundColor: 'rgba(255, 206, 86, 0.1)',
                borderWidth: 2,
                fill: true,
                tension: 0.4
            }
        ]
    };
    
    new Chart(trendChartElement, {
        type: 'line',
        data: trendData,
        options: {
            responsive: true,
            maintainAspectRatio: false,
            scales: {
                y: {
                    beginAtZero: true,
                    max: 100,
                    title: {
                        display: true,
                        text: 'Risk Level'
                    }
                }
            },
            plugins: {
                legend: {
                    position: 'top',
                },
                tooltip: {
                    mode: 'index',
                    intersect: false
                }
            }
        }
    });
}

// Risk impact vs probability matrix
function initRiskMatrix() {
    const matrixElement = document.getElementById('risk-matrix-chart');
    
    if (!matrixElement) return;
    
    // Sample data - in a real implementation, this would come from an API
    const matrixData = {
        datasets: [{
            label: 'Risk Factors',
            data: [
                { x: 85, y: 90, r: 15, label: 'Semiconductor Shortage' },
                { x: 75, y: 65, r: 12, label: 'Port Congestion' },
                { x: 60, y: 80, r: 14, label: 'Trade Restrictions' },
                { x: 40, y: 95, r: 13, label: 'Natural Disasters' },
                { x: 30, y: 50, r: 10, label: 'Labor Shortages' },
                { x: 55, y: 45, r: 11, label: 'Cybersecurity Threats' },
                { x: 25, y: 30, r: 8, label: 'Currency Fluctuations' },
                { x: 70, y: 20, r: 9, label: 'Regulatory Changes' }
            ],
            backgroundColor: [
                'rgba(255, 99, 132, 0.7)',
                'rgba(54, 162, 235, 0.7)',
                'rgba(255, 206, 86, 0.7)',
                'rgba(75, 192, 192, 0.7)',
                'rgba(153, 102, 255, 0.7)',
                'rgba(255, 159, 64, 0.7)',
                'rgba(201, 203, 207, 0.7)',
                'rgba(255, 99, 255, 0.7)'
            ],
            borderColor: [
                'rgba(255, 99, 132, 1)',
                'rgba(54, 162, 235, 1)',
                'rgba(255, 206, 86, 1)',
                'rgba(75, 192, 192, 1)',
                'rgba(153, 102, 255, 1)',
                'rgba(255, 159, 64, 1)',
                'rgba(201, 203, 207, 1)',
                'rgba(255, 99, 255, 1)'
            ],
            borderWidth: 1
        }]
    };
    
    const matrixChart = new Chart(matrixElement, {
        type: 'bubble',
        data: matrixData,
        options: {
            responsive: true,
            maintainAspectRatio: false,
            scales: {
                x: {
                    min: 0,
                    max: 100,
                    title: {
                        display: true,
                        text: 'Probability'
                    }
                },
                y: {
                    min: 0,
                    max: 100,
                    title: {
                        display: true,
                        text: 'Impact'
                    }
                }
            },
            plugins: {
                tooltip: {
                    callbacks: {
                        label: function(context) {
                            return context.raw.label + ' - Probability: ' + context.raw.x + '%, Impact: ' + context.raw.y + '%';
                        }
                    }
                }
            }
        }
    });
    
    // Add quadrant lines to the matrix
    const originalDraw = matrixChart.draw;
    matrixChart.draw = function() {
        originalDraw.apply(this, arguments);
        
        const chart = this;
        const ctx = chart.ctx;
        const xAxis = chart.scales.x;
        const yAxis = chart.scales.y;
        
        // Draw quadrant lines
        ctx.save();
        ctx.strokeStyle = 'rgba(0, 0, 0, 0.2)';
        ctx.lineWidth = 1;
        
        // Vertical line at x = 50
        ctx.beginPath();
        ctx.moveTo(xAxis.getPixelForValue(50), yAxis.getPixelForValue(0));
        ctx.lineTo(xAxis.getPixelForValue(50), yAxis.getPixelForValue(100));
        ctx.stroke();
        
        // Horizontal line at y = 50
        ctx.beginPath();
        ctx.moveTo(xAxis.getPixelForValue(0), yAxis.getPixelForValue(50));
        ctx.lineTo(xAxis.getPixelForValue(100), yAxis.getPixelForValue(50));
        ctx.stroke();
        
        // Add quadrant labels
        ctx.font = '12px Arial';
        ctx.fillStyle = 'rgba(0, 0, 0, 0.6)';
        ctx.textAlign = 'center';
        
        // Top-right quadrant - High Impact, High Probability
        ctx.fillText('Critical Risks', xAxis.getPixelForValue(75), yAxis.getPixelForValue(75));
        
        // Top-left quadrant - High Impact, Low Probability
        ctx.fillText('Major Risks', xAxis.getPixelForValue(25), yAxis.getPixelForValue(75));
        
        // Bottom-right quadrant - Low Impact, High Probability
        ctx.fillText('Moderate Risks', xAxis.getPixelForValue(75), yAxis.getPixelForValue(25));
        
        // Bottom-left quadrant - Low Impact, Low Probability
        ctx.fillText('Minor Risks', xAxis.getPixelForValue(25), yAxis.getPixelForValue(25));
        
        ctx.restore();
    };
    
    // Trigger a redraw to show the quadrant lines
    matrixChart.update();
}

// Initialize risk filters
function initRiskFilters() {
    const riskFilters = document.querySelectorAll('.risk-filter');
    const applyFiltersBtn = document.getElementById('apply-risk-filters');
    
    if (applyFiltersBtn) {
        applyFiltersBtn.addEventListener('click', function() {
            // In a real implementation, this would fetch new data based on filters
            // For this demo, we'll just show a loading indicator and then refresh the charts
            const riskContent = document.querySelector('.risk-analysis-content');
            
            if (riskContent) {
                // Add loading overlay
                const loadingOverlay = document.createElement('div');
                loadingOverlay.className = 'loading-overlay';
                loadingOverlay.innerHTML = '<div class="loading-spinner"></div><p>Updating risk analysis...</p>';
                riskContent.appendChild(loadingOverlay);
                
                // Simulate loading delay
                setTimeout(() => {
                    // Remove loading overlay
                    loadingOverlay.remove();
                    
                    // Show filter applied message
                    const filterMessage = document.createElement('div');
                    filterMessage.className = 'filter-applied-message';
                    filterMessage.textContent = 'Risk filters applied successfully!';
                    riskContent.appendChild(filterMessage);
                    
                    // Remove message after 3 seconds
                    setTimeout(() => {
                        filterMessage.remove();
                    }, 3000);
                    
                    // Update charts with "filtered" data (in reality, just random variations)
                    updateRiskChartsWithFilteredData();
                }, 1500);
            }
        });
    }
}

// Update risk charts with "filtered" data
function updateRiskChartsWithFilteredData() {
    // In a real implementation, this would use actual filtered data
    // For this demo, we'll just make random variations to the existing charts
    
    // Get all chart instances
    const charts = Object.values(Chart.instances);
    
    charts.forEach(chart => {
        // Apply random variations to each dataset
        chart.data.datasets.forEach(dataset => {
            if (dataset.data[0] && typeof dataset.data[0] === 'object') {
                // For bubble charts (risk matrix)
                dataset.data = dataset.data.map(point => {
                    // Random variation between -10% and +10%
                    const xVariation = 1 + (Math.random() * 0.2 - 0.1);
                    const yVariation = 1 + (Math.random() * 0.2 - 0.1);
                    
                    // Ensure values stay within bounds
                    const newX = Math.min(100, Math.max(0, Math.round(point.x * xVariation)));
                    const newY = Math.min(100, Math.max(0, Math.round(point.y * yVariation)));
                    
                    return {
                        x: newX,
                        y: newY,
                        r: point.r,
                        label: point.label
                    };
                });
            } else {
                // For other chart types
                dataset.data = dataset.data.map(value => {
                    if (value === null) return null; // Preserve null values
                    // Random variation between -10% and +10%
                    const variation = 1 + (Math.random() * 0.2 - 0.1);
                    return Math.min(100, Math.max(0, Math.round(value * variation)));
                });
            }
        });
        
        // Update the chart
        chart.update();
    });
}

// Initialize risk comparison tools
function initRiskComparison() {
    const compareBtn = document.getElementById('compare-risk-periods');
    
    if (compareBtn) {
        compareBtn.addEventListener('click', function() {
            // Toggle comparison mode
            this.classList.toggle('active');
            
            if (this.classList.contains('active')) {
                // Activate comparison mode
                this.textContent = 'Hide Comparison';
                showRiskComparison();
            } else {
                // Deactivate comparison mode
                this.textContent = 'Compare Periods';
                hideRiskComparison();
            }
        });
    }
}

// Show risk comparison data
function showRiskComparison() {
    // In a real implementation, this would fetch comparison data
    // For this demo, we'll just add comparison datasets to existing charts
    
    // Get the risk trend chart
    const trendChart = Chart.getChart(document.getElementById('risk-trend-chart'));
    
    if (trendChart) {
        // Add previous period datasets
        trendChart.data.datasets.push(
            {
                label: 'Geopolitical Risk (Previous Year)',
                data: [55, 58, 65, 71, 75, 73, 68, 65, 72, 75],
                borderColor: 'rgba(255, 99, 132, 0.5)',
                backgroundColor: 'transparent',
                borderWidth: 2,
                borderDash: [5, 5],
                fill: false,
                tension: 0.4
            },
            {
                label: 'Environmental Risk (Previous Year)',
                data: [45, 48, 52, 55, 62, 68, 65, 60, 58, 62],
                borderColor: 'rgba(54, 162, 235, 0.5)',
                backgroundColor: 'transparent',
                borderWidth: 2,
                borderDash: [5, 5],
                fill: false,
                tension: 0.4
            },
            {
                label: 'Economic Risk (Previous Year)',
                data: [60, 58, 55, 50, 48, 52, 55, 58, 53, 53],
                borderColor: 'rgba(255, 206, 86, 0.5)',
                backgroundColor: 'transparent',
                borderWidth: 2,
                borderDash: [5, 5],
                fill: false,
                tension: 0.4
            }
        );
        
        // Update the chart
        trendChart.update();
    }
    
    // Get the risk category chart
    const categoryChart = Chart.getChart(document.getElementById('risk-category-chart'));
    
    if (categoryChart) {
        // Add previous period dataset
        categoryChart.data.datasets.push({
            label: 'Previous Year Risk Level',
            data: [75, 62, 53, 40, 51, 58],
            backgroundColor: 'rgba(255, 99, 132, 0.3)',
            borderColor: 'rgba(255, 99, 132, 0.5)',
            borderWidth: 1,
            borderDash: [5, 5]
        });
        
        // Update the chart
        categoryChart.update();
    }
    
    // Add comparison summary
    const riskContent = document.querySelector('.risk-analysis-content');
    
    if (riskContent) {
        const comparisonSummary = document.createElement('div');
        comparisonSummary.className = 'comparison-summary';
        comparisonSummary.innerHTML = `
            <h3>Year-over-Year Risk Comparison</h3>
            <div class="comparison-grid">
                <div class="comparison-item">
                    <h4>Geopolitical Risk</h4>
                    <div class="comparison-value increase">+13.3%</div>
                    <p>Increased due to escalating tensions in key regions and trade disputes</p>
                </div>
                <div class="comparison-item">
                    <h4>Environmental Risk</h4>
                    <div class="comparison-value increase">+16.1%</div>
                    <p>Increased due to more frequent extreme weather events and natural disasters</p>
                </div>
                <div class="comparison-item">
                    <h4>Economic Risk</h4>
                    <div class="comparison-value increase">+18.9%</div>
                    <p>Increased due to inflation pressures and monetary policy uncertainty</p>
                </div>
                <div class="comparison-item">
                    <h4>Technological Risk</h4>
                    <div class="comparison-value increase">+12.5%</div>
                    <p>Increased due to rising cybersecurity threats and digital transformation challenges</p>
                </div>
                <div class="comparison-item">
                    <h4>Operational Risk</h4>
                    <div class="comparison-value increase">+9.8%</div>
                    <p>Increased due to labor shortages and capacity constraints</p>
                </div>
                <div class="comparison-item">
                    <h4>Regulatory Risk</h4>
                    <div class="comparison-value increase">+17.2%</div>
                    <p>Increased due to evolving compliance requirements and policy changes</p>
                </div>
            </div>
        `;
        
        // Insert after the first heading
        const firstHeading = riskContent.querySelector('h2');
        if (firstHeading) {
            firstHeading.parentNode.insertBefore(comparisonSummary, firstHeading.nextSibling);
        } else {
            riskContent.appendChild(comparisonSummary);
        }
    }
}

// Hide risk comparison data
function hideRiskComparison() {
    // Get the risk trend chart
    const trendChart = Chart.getChart(document.getElementById('risk-trend-chart'));
    
    if (trendChart) {
        // Remove comparison datasets (last 3)
        trendChart.data.datasets = trendChart.data.datasets.slice(0, 3);
        
        // Update the chart
        trendChart.update();
    }
    
    // Get the risk category chart
    const categoryChart = Chart.getChart(document.getElementById('risk-category-chart'));
    
    if (categoryChart) {
        // Remove comparison dataset (last one)
        categoryChart.data.datasets = categoryChart.data.datasets.slice(0, 1);
        
        // Update the chart
        categoryChart.update();
    }
    
    // Remove comparison summary
    const comparisonSummary = document.querySelector('.comparison-summary');
    if (comparisonSummary) {
        comparisonSummary.remove();
    }
}

// Initialize risk timeline
function initRiskTimeline() {
    const timelineElement = document.getElementById('risk-timeline');
    
    if (!timelineElement) return;
    
    // In a real implementation, this would fetch timeline data from an API
    // For this demo, we'll just add some sample timeline events
    const timelineEvents = [
        {
            date: 'March 15, 2025',
            title: 'Semiconductor Factory Shutdown',
            description: 'Major semiconductor factory in Taiwan temporarily closed due to power outages, affecting global chip supply.',
            impact: 'high',
            category: 'disruption'
        },
        {
            date: 'March 10, 2025',
            title: 'New Trade Restrictions Announced',
            description: 'Trade restrictions announced between major economies, potentially affecting cross-border supply chains.',
            impact: 'high',
            category: 'geopolitical'
        },
        {
            date: 'March 5, 2025',
            title: 'Port Congestion in Southeast Asia',
            description: 'Major ports experiencing significant congestion due to increased shipping volume and labor shortages.',
            impact: 'medium',
            category: 'disruption'
        },
        {
            date: 'February 28, 2025',
            title: 'Severe Weather Event',
            description: 'Hurricane disrupted shipping routes and damaged infrastructure in key logistics hubs.',
            impact: 'medium',
            category: 'environmental'
        },
        {
            date: 'February 20, 2025',
            title: 'New Regulatory Framework',
            description: 'New regulatory requirements announced for cross-border shipments, effective in 60 days.',
            impact: 'medium',
            category: 'regulatory'
        },
        {
            date: 'February 15, 2025',
            title: 'Major Cybersecurity Incident',
            description: 'Ransomware attack affected multiple logistics providers, disrupting operations for several days.',
            impact: 'high',
            category: 'technological'
        }
    ];
    
    // Create timeline HTML
    let timelineHTML = '<div class="timeline-container">';
    
    timelineEvents.forEach(event => {
        timelineHTML += `
            <div class="timeline-event">
                <div class="timeline-date">${event.date}</div>
                <div class="timeline-content">
                    <div class="timeline-header">
                        <h4 class="timeline-title">${event.title}</h4>
                        <span class="impact-badge ${event.impact}">${event.impact.charAt(0).toUpperCase() + event.impact.slice(1)} Impact</span>
                    </div>
                    <p class="timeline-description">${event.description}</p>
                    <span class="timeline-category">${event.category.charAt(0).toUpperCase() + event.category.slice(1)}</span>
                </div>
            </div>
        `;
    });
    
    timelineHTML += '</div>';
    
    // Add timeline to the page
    timelineElement.innerHTML = timelineHTML;
}

// Initialize risk factor analysis
function initRiskFactorAnalysis() {
    const riskFactorElements = document.querySelectorAll('.risk-factor-item');
    
    if (riskFactorElements.length === 0) return;
    
    riskFactorElements.forEach(factor => {
        const detailsBtn = factor.querySelector('.view-details-btn');
        const detailsContent = factor.querySelector('.factor-details');
        
        if (detailsBtn && detailsContent) {
            // Initially hide details
            detailsContent.style.display = 'none';
            
            detailsBtn.addEventListener('click', function() {
                // Toggle details visibility
                if (detailsContent.style.display === 'none') {
                    // Hide all other details first
                    document.querySelectorAll('.factor-details').forEach(content => {
                        content.style.display = 'none';
                    });
                    
                    // Show this factor's details
                    detailsContent.style.display = 'block';
                    detailsBtn.textContent = 'Hide Details';
                    
                    // Scroll to the details if needed
                    detailsContent.scrollIntoView({ behavior: 'smooth', block: 'nearest' });
                } else {
                    // Hide details
                    detailsContent.style.display = 'none';
                    detailsBtn.textContent = 'View Details';
                }
            });
        }
    });
}
